@@ -14,12 +14,13 @@ use boolean qw(true false);
 
 use Carp qw(croak);
 use DateTime ();
+use DateTime::TimeZone ();
 use List::MoreUtils qw(all any none);
 use Params::Validate ':all';
 use Scalar::Util qw(blessed);
 use Storable qw(dclone);
 
-our $VERSION = '0.97';
+our $VERSION = '0.99';
 
 validation_options(
     on_fail => sub
@@ -92,13 +93,19 @@ sub _init_check
             optional => true,
         },
         time_zone => {
-            type => SCALAR,
+            type => SCALAR | OBJECT,
             optional => true,
             callbacks => {
                 'valid timezone' => sub
                 {
-                    eval { DateTime::TimeZone->new(name => shift) };
-                    !$@;
+                    my $val = shift;
+                    if (blessed($val)) {
+                        return $val->isa('DateTime::TimeZone');
+                    }
+                    else {
+                        eval { DateTime::TimeZone->new(name => $val) };
+                        return !$@;
+                    }
                 }
             },
         },
@@ -175,6 +182,24 @@ sub parse_datetime
 
         $self->_set_valid_exp;
     }
+    elsif ($date_string =~ /^\d{14}$/) {
+        my %args;
+        @args{qw(year month day hour minute second)} = $date_string =~ /^(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})$/;
+
+        my $valid_date = $self->_check_date(map $args{$_}, qw(year month day));
+        my $valid_time = $self->_check_time(map $args{$_}, qw(hour minute second));
+
+        if (not $valid_date && $valid_time) {
+            my $type = !$valid_date ? 'date' : 'time';
+            $self->_set_failure;
+            $self->_set_error("(invalid $type)");
+            return $self->_get_datetime_object;
+        }
+
+        $self->_set(%args);
+
+        $self->_set_valid_exp;
+    }
     else {
         @{$self->{tokens}} = split /\s+/, $date_string;
         $self->{data}->__init('tokens')->($self);
@@ -207,6 +232,13 @@ sub _params_init
         validate_pos(@_, { type => SCALAR });
         (${$params->{string}}) = @_;
     }
+
+    ${$params->{string}} = do {
+        local $_ = ${$params->{string}};
+        s/^\s+//;
+        s/\s+$//;
+        $_;
+    };
 }
 
 sub _parse_init
@@ -770,10 +802,11 @@ valuable suggestions and patches:
  Colm Dougan
  Chifung Fan
  Xiao Yafeng
+ Roman Filippov
 
 =head1 SEE ALSO
 
-L<DateTime>, L<Date::Calc>, L<http://datetime.perl.org>
+L<dateparse>, L<DateTime>, L<Date::Calc>, L<http://datetime.perl.org>
 
 =head1 AUTHOR
 
